@@ -6,11 +6,11 @@ library("SuperLearner")
 set.seed(4747)
 p <- 2
 n <- 5e4
-x <- replicate(p, stats::rnorm(n, 0, 1))
+x <- as.data.frame(replicate(p, stats::rnorm(n, 0, 1)))
 # apply the function to the x's
 y <- 1 + 0.5 * x[, 1] + 0.75 * x[, 2] + stats::rnorm(n, 0, 1)
 # get the 'true' SPVIMs
-true_var <- mean((y - mean(y)) ^ 2)
+true_var <- 1 + .5 ^ 2 + .75 ^ 2
 mse_one <- mean((y - (1 + 0.5 * x[, 1])) ^ 2)
 mse_two <- mean((y - (1 + 0.75 * x[, 2])) ^ 2)
 mse_full <- mean((y - (1 + 0.5 * x[, 1] + 0.75 * x[, 2])) ^ 2)
@@ -22,10 +22,11 @@ shapley_val_1 <- (1/2) * (r2_one - 0) + (1/2) * (r2_full - r2_two)
 shapley_val_2 <- (1/2) * (r2_two - 0) + (1/2) * (r2_full - r2_one)
 
 # set up a library for SuperLearner
-learners <- c("SL.glm", "SL.mean")
+learners <- c("SL.glm")
 univariate_learners <- "SL.glm"
 V <- 2
 
+set.seed(1234)
 test_that("Estimating SPVIMs works", {
   est <- sp_vim(Y = y, X = x, V = V, type = "r_squared",
                 SL.library = learners, gamma = .1, alpha = 0.05, delta = 0,
@@ -42,6 +43,16 @@ test_that("Estimating SPVIMs works", {
   expect_silent(format(est)[1])
   expect_output(print(est), "Estimate", fixed = TRUE)
 })
+set.seed(1234)
+test_that("Estimating SPVIMs without sample-splitting works", {
+  est <- sp_vim(Y = y, X = x, V = V, type = "r_squared",
+                SL.library = learners, gamma = .1, alpha = 0.05, delta = 0,
+                sample_splitting = FALSE,
+                cvControl = list(V = V), env = environment())
+  # check that the estimate is approximately correct
+  expect_equal(as.numeric(est$est[2]), shapley_val_1, tolerance = 0.2)
+})
+set.seed(5678)
 test_that("Estimating SPVIMs with special univariate library works", {
   est <- sp_vim(Y = y, X = x, V = V, type = "r_squared",
                 SL.library = learners, 
@@ -51,6 +62,7 @@ test_that("Estimating SPVIMs with special univariate library works", {
   # check that the estimate is approximately correct
   expect_equal(as.numeric(est$est[2]), shapley_val_1, tolerance = 0.2)
 })
+set.seed(91011)
 test_that("Estimating SPVIMs with a single library function works", {
   est <- sp_vim(Y = y, X = x, V = V, type = "r_squared",
                 SL.library = "SL.glm", 
@@ -60,10 +72,11 @@ test_that("Estimating SPVIMs with a single library function works", {
   # check that the estimate is approximately correct
   expect_equal(as.numeric(est$est[2]), shapley_val_1, tolerance = 0.2)
 })
+set.seed(121314)
 test_that("Estimating SPVIMs with verbose = TRUE works", {
   expect_message(est <- sp_vim(Y = y, X = x, V = V, type = "r_squared",
                               SL.library = "SL.glm", 
-                              univariate_SL.library = univariate_learners,
+                              univariate_SL.library = "SL.glm",
                               gamma = .1, alpha = 0.05, delta = 0,
                               cvControl = list(V = V), env = environment(), 
                               verbose = TRUE),
